pub struct Account {
pub id: String,
pub name: String,
pub _type: Type,
pub on_budget: bool,
pub closed: bool,
pub note: Option<String>,
pub balance: i64,
pub cleared_balance: i64,
pub uncleared_balance: i64,
pub transfer_payee_id: String,
pub deleted: bool,
}Fields
id: Stringname: String_type: TypeThe type of account. Note: payPal, merchantAccount, investmentAccount, and mortgage types have been deprecated and will be removed in the future.
on_budget: boolWhether this account is on budget or not
closed: boolWhether this account is closed or not
note: Option<String>balance: i64The current balance of the account in milliunits format
cleared_balance: i64The current cleared balance of the account in milliunits format
uncleared_balance: i64The current uncleared balance of the account in milliunits format
transfer_payee_id: StringThe payee id which should be used when transferring to this account
deleted: boolWhether or not the account has been deleted. Deleted accounts will only be included in delta requests.
Implementations