ynab_api::models::category

Struct Category

pub struct Category {
Show 15 fields pub id: String, pub category_group_id: String, pub name: String, pub hidden: bool, pub original_category_group_id: Option<String>, pub note: Option<String>, pub budgeted: i64, pub activity: i64, pub balance: i64, pub goal_type: Option<GoalType>, pub goal_creation_month: Option<String>, pub goal_target: Option<i64>, pub goal_target_month: Option<String>, pub goal_percentage_complete: Option<i32>, pub deleted: bool,
}

Fields

id: Stringcategory_group_id: Stringname: Stringhidden: bool

Whether or not the category is hidden

original_category_group_id: Option<String>

If category is hidden this is the id of the category group it originally belonged to before it was hidden.

note: Option<String>budgeted: i64

Budgeted amount in milliunits format

activity: i64

Activity amount in milliunits format

balance: i64

Balance in milliunits format

goal_type: Option<GoalType>

The type of goal, if the category has a goal (TB=Target Category Balance, TBD=Target Category Balance by Date, MF=Monthly Funding)

goal_creation_month: Option<String>

The month a goal was created

goal_target: Option<i64>

The goal target amount in milliunits

goal_target_month: Option<String>

If the goal type is ‘TBD’ (Target Category Balance by Date), this is the target month for the goal to be completed

goal_percentage_complete: Option<i32>

The percentage completion of the goal

deleted: bool

Whether or not the category has been deleted. Deleted categories will only be included in delta requests.

Implementations

Source

impl Category

pub fn new( id: String, category_group_id: String, name: String, hidden: bool, budgeted: i64, activity: i64, balance: i64, deleted: bool, ) -> Category