pub struct CategoryGroup {
pub id: String,
pub name: String,
pub hidden: bool,
pub deleted: bool,
}Fields
id: Stringname: StringWhether or not the category group is hidden
deleted: boolWhether or not the category group has been deleted. Deleted category groups will only be included in delta requests.
Implementations
Sourceimpl CategoryGroup
impl CategoryGroup