ynab_api::models::date_format

Struct DateFormat

pub struct DateFormat {
    pub format: String,
}
DateFormat : The date format setting for the budget. In some cases the format will not be available and will be specified as null.

Fields

format: String

Implementations

Source

impl DateFormat

pub fn new(format: String) -> DateFormat

The date format setting for the budget. In some cases the format will not be available and will be specified as null.