pub struct HybridTransaction {Show 20 fields
pub id: String,
pub date: String,
pub amount: i64,
pub memo: Option<String>,
pub cleared: Cleared,
pub approved: bool,
pub flag_color: Option<FlagColor>,
pub account_id: String,
pub payee_id: Option<String>,
pub category_id: Option<String>,
pub transfer_account_id: Option<String>,
pub transfer_transaction_id: Option<String>,
pub matched_transaction_id: Option<String>,
pub import_id: Option<String>,
pub deleted: bool,
pub _type: Type,
pub parent_transaction_id: Option<String>,
pub account_name: String,
pub payee_name: Option<String>,
pub category_name: Option<String>,
}Fields
id: Stringdate: StringThe transaction date in ISO format (e.g. 2016-12-01)
amount: i64The transaction amount in milliunits format
memo: Option<String>cleared: ClearedThe cleared status of the transaction
approved: boolWhether or not the transaction is approved
flag_color: Option<FlagColor>The transaction flag
account_id: Stringpayee_id: Option<String>category_id: Option<String>transfer_account_id: Option<String>If a transfer transaction, the account to which it transfers
transfer_transaction_id: Option<String>If a transfer transaction, the id of transaction on the other side of the transfer
matched_transaction_id: Option<String>If transaction is matched, the id of the matched transaction
import_id: Option<String>If the Transaction was imported, this field is a unique (by account) import identifier. If this transaction was imported through File Based Import or Direct Import and not through the API, the import_id will have the format: ‘YNAB:[milliunit_amount]:[iso_date]:[occurrence]’. For example, a transaction dated 2015-12-30 in the amount of -$294.23 USD would have an import_id of ‘YNAB:-294230:2015-12-30:1’. If a second transaction on the same account was imported and had the same date and same amount, its import_id would be ‘YNAB:-294230:2015-12-30:2’.
deleted: boolWhether or not the transaction has been deleted. Deleted transactions will only be included in delta requests.
_type: TypeWhether the hybrid transaction represents a regular transaction or a subtransaction
parent_transaction_id: Option<String>For subtransaction types, this is the id of the parent transaction. For transaction types, this id will be always be null.
account_name: Stringpayee_name: Option<String>category_name: Option<String>Implementations