pub struct MonthSummary {
pub month: String,
pub note: Option<String>,
pub income: i64,
pub budgeted: i64,
pub activity: i64,
pub to_be_budgeted: i64,
pub age_of_money: Option<i32>,
pub deleted: bool,
}Fields
month: Stringnote: Option<String>income: i64The total amount in transactions categorized to ‘Inflow: To be Budgeted’ in the month
budgeted: i64The total amount budgeted in the month
activity: i64The total amount in transactions in the month, excluding those categorized to ‘Inflow: To be Budgeted’
to_be_budgeted: i64The available amount for ‘To be Budgeted’
age_of_money: Option<i32>The Age of Money as of the month
deleted: boolWhether or not the month has been deleted. Deleted months will only be included in delta requests.
Implementations