[−][src]Struct ynab_api::models::ScheduledSubTransaction
Fields
id: Stringscheduled_transaction_id: Stringamount: i64The scheduled subtransaction amount in milliunits format
memo: Option<String>payee_id: Option<String>category_id: Stringtransfer_account_id: Option<String>If a transfer, the account_id which the scheduled subtransaction transfers to
deleted: boolWhether or not the scheduled subtransaction has been deleted. Deleted scheduled subtransactions will only be included in delta requests.
Methods
impl ScheduledSubTransaction[src]
pub fn new(
id: String,
scheduled_transaction_id: String,
amount: i64,
category_id: String,
deleted: bool
) -> ScheduledSubTransaction[src]
id: String,
scheduled_transaction_id: String,
amount: i64,
category_id: String,
deleted: bool
) -> ScheduledSubTransaction