pub struct SaveTransaction {
pub account_id: String,
pub date: String,
pub amount: i64,
pub payee_id: Option<String>,
pub payee_name: Option<String>,
pub category_id: Option<String>,
pub memo: Option<String>,
pub cleared: Option<Cleared>,
pub approved: Option<bool>,
pub flag_color: Option<FlagColor>,
pub import_id: Option<String>,
}Fields
account_id: Stringdate: StringThe transaction date in ISO format (e.g. 2016-12-01). Future dates (scheduled transactions) are not permitted. Split transaction dates cannot be changed and if a different date is supplied it will be ignored.
amount: i64The transaction amount in milliunits format. Split transaction amounts cannot be changed and if a different amount is supplied it will be ignored.
payee_id: Option<String>The payee for the transaction. To create a transfer between two accounts, use the account transfer payee pointing to the target account. Account transfer payees are specified as tranfer_payee_id on the account resource.
payee_name: Option<String>The payee name. If a payee_name value is provided and payee_id has a null value, the payee_name value will be used to resolve the payee by either (1) a matching payee rename rule (only if import_id is also specified) or (2) a payee with the same name or (3) creation of a new payee.
category_id: Option<String>The category for the transaction. Split and Credit Card Payment categories are not permitted and will be ignored if supplied. If an existing transaction has a Split category it cannot be changed.
memo: Option<String>cleared: Option<Cleared>The cleared status of the transaction
approved: Option<bool>Whether or not the transaction is approved. If not supplied, transaction will be unapproved by default.
flag_color: Option<FlagColor>The transaction flag
import_id: Option<String>If specified, the new transaction will be assigned this import_id and considered "imported". We will also attempt to match this imported transaction to an existing "user-entered" transation on the same account, with the same amount, and with a date +/-10 days from the imported transaction date.
Transactions imported through File Based Import or Direct Import (not through the API) are assigned an import_id in the format: ‘YNAB:[milliunit_amount]:[iso_date]:[occurrence]’. For example, a transaction dated 2015-12-30 in the amount of -$294.23 USD would have an import_id of ‘YNAB:-294230:2015-12-30:1’. If a second transaction on the same account was imported and had the same date and same amount, its import_id would be ‘YNAB:-294230:2015-12-30:2’. Using a consistent format will prevent duplicates through Direct Import and File Based Import.
If import_id is omitted or specified as null, the transaction will be treated as a "user-entered" transaction. As such, it will be eligible to be matched against transactions later being imported (via DI, FBI, or API).
Implementations